@@ -1,21 +1,3 @@
-## Copyright 2012-2014 Sebastian Gibb
-## <mail@sebastiangibb.de>
-##
-## This file is part of MALDIquant for R and related languages.
-##
-## MALDIquant is free software: you can redistribute it and/or modify
-## it under the terms of the GNU General Public License as published by
-## the Free Software Foundation, either version 3 of the License, or
-## (at your option) any later version.
-##
-## MALDIquant is distributed in the hope that it will be useful,
-## but WITHOUT ANY WARRANTY; without even the implied warranty of
-## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-## GNU General Public License for more details.
-##
-## You should have received a copy of the GNU General Public License
-## along with MALDIquant. If not, see <http://www.gnu.org/licenses/>
-
 ## determineWarpingFunctions
 ##  calculates warping functions for each MassPeaks object
 ##
@@ -102,11 +84,10 @@ determineWarpingFunctions <- function(l, reference, tolerance=0.002,
   intensities <- .unlist(lapply(tmpPeakList, function(x)x@intensity))
 
   ## store original mass sample number/id
-  samples <- rep.int(seq_along(tmpPeakList),
-                     .unlist(lapply(tmpPeakList, length)))
+  samples <- rep.int(seq_along(tmpPeakList), lengths(tmpPeakList))
 
   ## sort values by mass
-  s <- sort.int(mass, method="quick", index.return=TRUE)
+  s <- sort.int(mass, index.return=TRUE)
 
   mass <- s$x
   intensities <- intensities[s$ix]
@@ -122,7 +103,7 @@ determineWarpingFunctions <- function(l, reference, tolerance=0.002,
   lIdx <- split(seq_along(binnedMass), samples)
 
   ## calculate differences
-  binnedMass[binnedMass == 0L] <- NA
+  binnedMass[binnedMass == 0L] <- NA_real_
   d <- binnedMass - mass
 
   ## each function which determines a warping function uses these 3 arguments
@@ -157,12 +138,12 @@ determineWarpingFunctions <- function(l, reference, tolerance=0.002,
 
     if (!isNonInteractivePlot && !plotInteractive) {
       warning(sQuote("plot"), " is ", sQuote("TRUE"),
-              " but no non-interactive devices is available. ",
+              " but no non-interactive device is available. ",
               "Using pdf() to create a default one.")
       pdf(paper="a4r", width=12)
     } else if (dev.cur() == 1L && plotInteractive) {
       warning(sQuote("plot"), " is ", sQuote("TRUE"),
-              " but no interactive devices is available. ",
+              " but no interactive device is available. ",
               "Using dev.new() to create a default one.")
       dev.new()
     }
