@@ -1,25 +1,8 @@
-## Copyright 2011-2013 Sebastian Gibb
-## <mail@sebastiangibb.de>
-##
-## This file is part of MALDIquant for R and related languages.
-##
-## MALDIquant is free software: you can redistribute it and/or modify
-## it under the terms of the GNU General Public License as published by
-## the Free Software Foundation, either version 3 of the License, or
-## (at your option) any later version.
-##
-## MALDIquant is distributed in the hope that it will be useful,
-## but WITHOUT ANY WARRANTY; without even the implied warranty of
-## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-## GNU General Public License for more details.
-##
-## You should have received a copy of the GNU General Public License
-## along with MALDIquant. If not, see <http://www.gnu.org/licenses/>
-
 ## AbstractMassObject
 setMethod(f="plot",
           signature=signature(x="AbstractMassObject", y="missing"),
-          definition=function(x, col="black", xlab="mass", ylab="intensity",
+          definition=function(x, col="black",
+                              xlab=expression(italic(m/z)), ylab="intensity",
                               type=ifelse(isMassPeaks(x), "h", "l"),
                               xlim=c(ifelse(length(x@mass),
                                             min(x@mass, na.rm=TRUE), 0L),
